/* dck.c: dock snapshot (Warajevo .DCK) handling routines
   Copyright (c) 2003 Darren Salt, Fredrick Meunier

   $Id: dck.h,v 1.2 2004/05/25 10:05:06 fredm Exp $

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

   Author contact information:

   Philip: pak21-fuse@srcf.ucam.org
   Postal address: 15 Crescent Road, Wokingham, Berks, RG40 2DB, England

   Darren: linux@youmustbejoking.demon.co.uk
   Fred: fredm@spamcop.net

*/

#ifndef FUSE_DCK_H
#define FUSE_DCK_H

/* Dock cart inserted? */
extern int dck_active;

int dck_insert( const char *filename );
void dck_eject( void );
int dck_reset( void );

#endif
